@@ -21,7 +21,11 @@ from semantic_release.commit_parser.token import (
     ParseError,
     ParseResult,
 )
-from semantic_release.commit_parser.util import breaking_re, parse_paragraphs
+from semantic_release.commit_parser.util import (
+    breaking_re,
+    parse_paragraphs,
+    sort_numerically,
+)
 from semantic_release.enums import LevelBump
 from semantic_release.errors import InvalidParserOptions
 
@@ -195,7 +199,7 @@ class AngularCommitParser(CommitParser[ParseResult, AngularParserOptions]):
                     predicate.split(","),
                 )
             )
-            accumulator["linked_issues"] = sorted(
+            accumulator["linked_issues"] = sort_numerically(
                 set(accumulator["linked_issues"]).union(new_issue_refs)
             )
             # TODO: breaking change v10, removes resolution footers from descriptions
